#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Pythonic, XML Templating

Kid is a simple, Python-based template language for generating and
transforming XML vocabularies. Kid was spawned as a result of a kinky love
triangle between XSLT, TAL, and PHP. We believe many of the best features
of these languages live on in Kid with much of the limitations and
complexity stamped out (well, eventually :).

"""

__revision__ = "$Rev: 497 $"
__date__ = "$Date: 2007-07-16 14:48:50 -0400 (Mon, 16 Jul 2007) $"

version = "0.9.6"
author = "Ryan Tomayko"
email = "rtomayko@gmail.com"
copyright = "Copyright 2004-2006, Ryan Tomayko, " \
    "David Stanek, Christoph Zwerschke, Daniel Miller"
license = "MIT" # http://www.opensource.org/licenses/mit-license.php
long_description = '\n'.join(__doc__.splitlines()[1:]).strip()
